#!/usr/bin/env bash

set -o errexit -o nounset

function usage {
    echo "Usage: framework [-d|-r] [parent_directory]

    This script sets up the directory structure required for CASA and CARTA processing.
    The path to the intended parent working directory is required when this script is called.

    Options:
    -d, --directory   parent_directory for CASA processing
    -r, --rawdata     make only rawdata directory in the given directory
    -h, --help        display help and exit
    "
}

choice=$(echo "$1" | tr A-Z a-z)
case $choice in
  --directory|-d)
      action="makeDir"
  ;;
  --rawdata|-r)
      action="makeRawdata"
  ;;
  --help|-h)
      usage
  ;;
esac

directory=$2

if [ $action = "makeDir" ]; then
    if [ -d "$directory" ]; then
      echo "Directory \"$directory\" exists, creating framework:"
      cd "$directory"

      echo "Creating rawdata/"
      mkdir "rawdata"
      chmod 777 rawdata

      echo "Creating working/"
      mkdir "working"
      chmod 770 working

      echo "Creating products/"
      mkdir "products"
      chmod 770 products

      echo "Directory framework complete. Ready to process."
    else
      echo "Directory $directory does not exist. Exiting."
      exit 1
    fi
fi

if [ $action = "makeRawdata" ]; then
    if [ -d "$directory" ]; then
      echo "Directory \"$directory\" exists, creating framework:"
      cd "$directory"

      echo "Creating rawdata/"
      mkdir "rawdata"
      chmod 777 rawdata

      echo "Directory framework complete. Ready to proceed."
    else
      echo "Directory \"$directory\" does not exist. Exiting."
      exit 1
    fi
fi
